@@ -1,11 +1,11 @@
 """mlops is a package for conducting MLOps, including versioning of datasets and
 models."""
 
-__version__ = '0.0.7'
+__version__ = '0.0.11'
 
-#import mlops.dataset
-#import mlops.errors
-#import mlops.model
+import mlops.dataset
+import mlops.errors
+import mlops.model
 
 __all__ = [
     '__version__',
